"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SimpleWsClient = void 0;
const reconnecting_websocket_1 = __importDefault(require("reconnecting-websocket"));
const constants_1 = require("../constants");
class SimpleWsClient extends reconnecting_websocket_1.default {
    _alive;
    on = this.addEventListener;
    off = this.removeEventListener;
    constructor(url, protocols, options) {
        super(url, protocols, options);
        this._alive = false;
        this.onMessage('ping', () => {
            this._alive = true;
            this.sendMessage('pong', undefined);
        });
        setInterval(() => {
            // @ts-expect-error - this._shouldReconnect is a private property of extended ReconnectingWebSocket instance
            const shouldReconnect = this._shouldReconnect;
            if (!this._alive && shouldReconnect) {
                this.reconnect();
            }
            this._alive = false;
        }, constants_1.HEALTH_CHECK_INTERVAL);
    }
    sendMessage(type, data) {
        this.send(JSON.stringify({ type, data }));
    }
    onMessage(type, callback) {
        const onMessage = (event) => {
            try {
                const message = JSON.parse(event.data.toString());
                if (type === message.type) {
                    callback(message.data);
                }
            }
            catch { }
        };
        this.addEventListener('message', onMessage);
        return () => {
            this.removeEventListener('message', onMessage);
        };
    }
}
exports.SimpleWsClient = SimpleWsClient;
//# sourceMappingURL=SimpleWsClient.js.map