"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SimpleWsWebSocket = void 0;
const ws_1 = require("ws");
const uuid_1 = require("uuid");
class SimpleWsWebSocket extends ws_1.WebSocket {
    id;
    metadata;
    _rooms;
    _alive;
    constructor(...args) {
        // @ts-ignore
        super(...args);
        this.id = (0, uuid_1.v4)();
        this.metadata = new Map();
        this._rooms = new Set();
        this._alive = true;
        this.onMessage('pong', () => {
            this._alive = true;
        });
        this.onMessage('ping', () => {
            this.ping();
            this.sendMessage('pong', undefined);
        });
    }
    _healthCheck() {
        if (!this._alive) {
            try {
                this.terminate();
            }
            catch { }
            return;
        }
        this._alive = false;
        this.sendMessage('ping', undefined);
    }
    sendMessage(type, data) {
        this.send(JSON.stringify({ type, data }));
    }
    onMessage(type, callback) {
        const onMessage = (raw) => {
            try {
                const message = JSON.parse(raw.toString());
                if (type === message.type) {
                    callback(message.data);
                }
            }
            catch { }
        };
        this.on('message', onMessage);
        return () => {
            this.off('message', onMessage);
        };
    }
    get rooms() {
        return this._rooms;
    }
    joinRoom(roomId) {
        this.rooms.add(roomId);
    }
    leaveRoom(roomId) {
        this.rooms.delete(roomId);
    }
}
exports.SimpleWsWebSocket = SimpleWsWebSocket;
//# sourceMappingURL=SimpleWsWebSocket.js.map